"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.configureAuthorizationEndpoint = void 0;
const router_1 = require("../../shared/router");
const OpenId4VcSiopVerifierService_1 = require("../OpenId4VcSiopVerifierService");
function configureAuthorizationEndpoint(router, config) {
    router.post(config.endpointPath, async (request, response, next) => {
        const { agentContext, verifier } = (0, router_1.getRequestContext)(request);
        try {
            const openId4VcVerifierService = agentContext.dependencyManager.resolve(OpenId4VcSiopVerifierService_1.OpenId4VcSiopVerifierService);
            const isVpRequest = request.body.presentation_submission !== undefined;
            const authorizationResponse = request.body;
            if (isVpRequest)
                authorizationResponse.presentation_submission = JSON.parse(request.body.presentation_submission);
            // FIXME: we should emit an event here and in other places
            await openId4VcVerifierService.verifyAuthorizationResponse(agentContext, {
                authorizationResponse: request.body,
                verifier,
            });
            response.status(200).send();
        }
        catch (error) {
            (0, router_1.sendErrorResponse)(response, agentContext.config.logger, 500, 'invalid_request', error);
        }
        // NOTE: if we don't call next, the agentContext session handler will NOT be called
        next();
    });
}
exports.configureAuthorizationEndpoint = configureAuthorizationEndpoint;
//# sourceMappingURL=authorizationEndpoint.js.map